# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: realtime.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'realtime.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0erealtime.proto\x12\x1b\x65u.deepslate.realtime.speeq\x1a\x1cgoogle/protobuf/struct.proto\"u\n\x0eToolDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x0e\n\x0c_description\"e\n\x1cUpdateToolDefinitionsRequest\x12\x45\n\x10tool_definitions\x18\x01 \x03(\x0b\x32+.eu.deepslate.realtime.speeq.ToolDefinition\"X\n\x0fToolCallRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\".\n\x10ToolCallResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\t\"*\n\x08\x44uration\x12\x0f\n\x07seconds\x18\x01 \x01(\x04\x12\r\n\x05nanos\x18\x02 \x01(\r\"\x86\x01\n\x16\x41udioLineConfiguration\x12\x13\n\x0bsample_rate\x18\x01 \x01(\r\x12\x15\n\rchannel_count\x18\x02 \x01(\r\x12@\n\rsample_format\x18\x03 \x01(\x0e\x32).eu.deepslate.realtime.speeq.SampleFormat\"\x85\x02\n\x10VadConfiguration\x12\x1c\n\x14\x63onfidence_threshold\x18\x01 \x01(\x02\x12\x12\n\nmin_volume\x18\x02 \x01(\x02\x12=\n\x0estart_duration\x18\x03 \x01(\x0b\x32%.eu.deepslate.realtime.speeq.Duration\x12<\n\rstop_duration\x18\x04 \x01(\x0b\x32%.eu.deepslate.realtime.speeq.Duration\x12\x42\n\x13\x62\x61\x63kbuffer_duration\x18\x05 \x01(\x0b\x32%.eu.deepslate.realtime.speeq.Duration\"D\n\x16InferenceConfiguration\x12\x15\n\rsystem_prompt\x18\x01 \x01(\t\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"\x8c\x02\n\x1a\x45levenLabsTtsConfiguration\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x10\n\x08voice_id\x18\x02 \x01(\t\x12\x15\n\x08model_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12Q\n\x0evoice_settings\x18\x04 \x01(\x0b\x32\x34.eu.deepslate.realtime.speeq.ElevenLabsVoiceSettingsH\x01\x88\x01\x01\x12\x41\n\x08location\x18\x05 \x01(\x0e\x32/.eu.deepslate.realtime.speeq.ElevenLabsLocationB\x0b\n\t_model_idB\x11\n\x0f_voice_settings\"\x7f\n\x17\x45levenLabsVoiceSettings\x12\x11\n\tstability\x18\x01 \x01(\x01\x12\x18\n\x10similarity_boost\x18\x02 \x01(\x01\x12\r\n\x05style\x18\x03 \x01(\x01\x12\x19\n\x11use_speaker_boost\x18\x04 \x01(\x08\x12\r\n\x05speed\x18\x05 \x01(\x01\"\"\n\x0eHostedVoiceRef\x12\x10\n\x08voice_id\x18\x01 \x01(\t\"c\n\x16HostedTtsConfiguration\x12@\n\tvoice_ref\x18\x01 \x01(\x0b\x32+.eu.deepslate.realtime.speeq.HostedVoiceRefH\x00\x42\x07\n\x05voice\"\xb5\x01\n\x10TtsConfiguration\x12N\n\x0b\x65leven_labs\x18\x01 \x01(\x0b\x32\x37.eu.deepslate.realtime.speeq.ElevenLabsTtsConfigurationH\x00\x12\x45\n\x06hosted\x18\x02 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.HostedTtsConfigurationH\x00\x42\n\n\x08provider\"\xe3\x03\n\x18InitializeSessionRequest\x12M\n\x10input_audio_line\x18\x01 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.AudioLineConfiguration\x12N\n\x11output_audio_line\x18\x02 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.AudioLineConfiguration\x12H\n\x11vad_configuration\x18\x03 \x01(\x0b\x32-.eu.deepslate.realtime.speeq.VadConfiguration\x12T\n\x17inference_configuration\x18\x04 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.InferenceConfiguration\x12M\n\x11tts_configuration\x18\x05 \x01(\x0b\x32-.eu.deepslate.realtime.speeq.TtsConfigurationH\x00\x88\x01\x01\x12#\n\x1bsupports_playback_reporting\x18\x06 \x01(\x08\x42\x14\n\x12_tts_configuration\"\xfb\x01\n\x19ReconfigureSessionRequest\x12R\n\x10input_audio_line\x18\x01 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.AudioLineConfigurationH\x00\x88\x01\x01\x12Y\n\x17inference_configuration\x18\x02 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.InferenceConfigurationH\x01\x88\x01\x01\x42\x13\n\x11_input_audio_lineB\x1a\n\x18_inference_configuration\"\x19\n\tAudioData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x18\n\x08TextData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\xe2\x01\n\tUserInput\x12\x11\n\tpacket_id\x18\x01 \x01(\x04\x12?\n\x04mode\x18\x02 \x01(\x0e\x32\x31.eu.deepslate.realtime.speeq.InferenceTriggerMode\x12<\n\naudio_data\x18\x03 \x01(\x0b\x32&.eu.deepslate.realtime.speeq.AudioDataH\x00\x12:\n\ttext_data\x18\x04 \x01(\x0b\x32%.eu.deepslate.realtime.speeq.TextDataH\x00\x42\x07\n\x05input\"J\n\x10TriggerInference\x12\x1f\n\x12\x65xtra_instructions\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_extra_instructions\"1\n\x18\x45xportChatHistoryRequest\x12\x15\n\rawait_pending\x18\x01 \x01(\x08\".\n\x16PlaybackPositionReport\x12\x14\n\x0c\x62ytes_played\x18\x01 \x01(\x04\"8\n\x0c\x44irectSpeech\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x1a\n\x12include_in_history\x18\x02 \x01(\x08\"_\n\x11\x43onversationQuery\x12\x13\n\x06prompt\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cinstructions\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_promptB\x0f\n\r_instructions\"\'\n\x17\x43onversationQueryResult\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xe2\x06\n\x13ServiceBoundMessage\x12[\n\x1ainitialize_session_request\x18\x01 \x01(\x0b\x32\x35.eu.deepslate.realtime.speeq.InitializeSessionRequestH\x00\x12]\n\x1breconfigure_session_request\x18\x02 \x01(\x0b\x32\x36.eu.deepslate.realtime.speeq.ReconfigureSessionRequestH\x00\x12<\n\nuser_input\x18\x03 \x01(\x0b\x32&.eu.deepslate.realtime.speeq.UserInputH\x00\x12\x64\n\x1fupdate_tool_definitions_request\x18\x04 \x01(\x0b\x32\x39.eu.deepslate.realtime.speeq.UpdateToolDefinitionsRequestH\x00\x12K\n\x12tool_call_response\x18\x05 \x01(\x0b\x32-.eu.deepslate.realtime.speeq.ToolCallResponseH\x00\x12J\n\x11trigger_inference\x18\x06 \x01(\x0b\x32-.eu.deepslate.realtime.speeq.TriggerInferenceH\x00\x12\\\n\x1b\x65xport_chat_history_request\x18\x07 \x01(\x0b\x32\x35.eu.deepslate.realtime.speeq.ExportChatHistoryRequestH\x00\x12W\n\x18playback_position_report\x18\x08 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.PlaybackPositionReportH\x00\x12\x42\n\rdirect_speech\x18\t \x01(\x0b\x32).eu.deepslate.realtime.speeq.DirectSpeechH\x00\x12L\n\x12\x63onversation_query\x18\n \x01(\x0b\x32..eu.deepslate.realtime.speeq.ConversationQueryH\x00\x42\t\n\x07payload\"!\n\x11ModelTextFragment\x12\x0c\n\x04text\x18\x01 \x01(\t\"p\n\x0fModelAudioChunk\x12\x35\n\x05\x61udio\x18\x01 \x01(\x0b\x32&.eu.deepslate.realtime.speeq.AudioData\x12\x17\n\ntranscript\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_transcript\"I\n\x0b\x43hatHistory\x12:\n\x08messages\x18\x01 \x03(\x0b\x32(.eu.deepslate.realtime.speeq.ChatMessage\"\xe8\x01\n\x0b\x43hatMessage\x12:\n\x04role\x18\x01 \x01(\x0e\x32,.eu.deepslate.realtime.speeq.ChatMessageRole\x12@\n\x07\x63ontent\x18\x02 \x03(\x0b\x32/.eu.deepslate.realtime.speeq.ChatMessageContent\x12H\n\x0f\x64\x65livery_status\x18\x03 \x01(\x0e\x32/.eu.deepslate.realtime.speeq.ChatDeliveryStatus\x12\x11\n\tephemeral\x18\x04 \x01(\x08\"\xdd\x02\n\x12\x43hatMessageContent\x12\x44\n\x0ctext_content\x18\x01 \x01(\x0b\x32,.eu.deepslate.realtime.speeq.ChatTextContentH\x00\x12\x41\n\x0binput_audio\x18\x02 \x01(\x0b\x32*.eu.deepslate.realtime.speeq.ChatAudioDataH\x00\x12\x12\n\x08thoughts\x18\x03 \x01(\tH\x00\x12\x41\n\ttool_call\x18\x04 \x01(\x0b\x32,.eu.deepslate.realtime.speeq.ToolCallRequestH\x00\x12\x44\n\x0btool_result\x18\x05 \x01(\x0b\x32-.eu.deepslate.realtime.speeq.ToolCallResponseH\x00\x12\x16\n\x0cinstructions\x18\x06 \x01(\tH\x00\x42\t\n\x07\x63ontent\"q\n\x0f\x43hatTextContent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x42\n\ttts_audio\x18\x02 \x01(\x0b\x32*.eu.deepslate.realtime.speeq.ChatAudioDataH\x00\x88\x01\x01\x42\x0c\n\n_tts_audio\"\xa2\x01\n\rChatAudioData\x12\x35\n\x05\x61udio\x18\x01 \x01(\x0b\x32&.eu.deepslate.realtime.speeq.AudioData\x12\x43\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x33.eu.deepslate.realtime.speeq.AudioLineConfiguration\x12\x15\n\rtranscription\x18\x03 \x01(\t\"\x15\n\x13PlaybackClearBuffer\"\x0f\n\rResponseBegin\"\r\n\x0bResponseEnd\"\x94\x01\n\x18SessionErrorNotification\x12\x43\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32\x31.eu.deepslate.realtime.speeq.SessionErrorCategory\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\x08trace_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_trace_id\"J\n\x17UserTranscriptionResult\x12\x0f\n\x07turn_id\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\"\x9f\x06\n\x12\x43lientBoundMessage\x12I\n\x11tool_call_request\x18\x01 \x01(\x0b\x32,.eu.deepslate.realtime.speeq.ToolCallRequestH\x00\x12M\n\x13model_text_fragment\x18\x02 \x01(\x0b\x32..eu.deepslate.realtime.speeq.ModelTextFragmentH\x00\x12I\n\x11model_audio_chunk\x18\x03 \x01(\x0b\x32,.eu.deepslate.realtime.speeq.ModelAudioChunkH\x00\x12Q\n\x15playback_clear_buffer\x18\x04 \x01(\x0b\x32\x30.eu.deepslate.realtime.speeq.PlaybackClearBufferH\x00\x12\x44\n\x0eresponse_begin\x18\x05 \x01(\x0b\x32*.eu.deepslate.realtime.speeq.ResponseBeginH\x00\x12@\n\x0cresponse_end\x18\x06 \x01(\x0b\x32(.eu.deepslate.realtime.speeq.ResponseEndH\x00\x12@\n\x0c\x63hat_history\x18\x07 \x01(\x0b\x32(.eu.deepslate.realtime.speeq.ChatHistoryH\x00\x12\x46\n\x05\x65rror\x18\x08 \x01(\x0b\x32\x35.eu.deepslate.realtime.speeq.SessionErrorNotificationH\x00\x12Y\n\x19user_transcription_result\x18\t \x01(\x0b\x32\x34.eu.deepslate.realtime.speeq.UserTranscriptionResultH\x00\x12Y\n\x19\x63onversation_query_result\x18\n \x01(\x0b\x32\x34.eu.deepslate.realtime.speeq.ConversationQueryResultH\x00\x42\t\n\x07payload*l\n\x0cSampleFormat\x12\x12\n\x0eUNSIGNED_8_BIT\x10\x00\x12\x11\n\rSIGNED_16_BIT\x10\x01\x12\x11\n\rSIGNED_32_BIT\x10\x02\x12\x10\n\x0c\x46LOAT_32_BIT\x10\x03\x12\x10\n\x0c\x46LOAT_64_BIT\x10\x04*/\n\x12\x45levenLabsLocation\x12\x06\n\x02US\x10\x00\x12\x06\n\x02\x45U\x10\x01\x12\t\n\x05INDIA\x10\x02*@\n\x14InferenceTriggerMode\x12\x0e\n\nNO_TRIGGER\x10\x00\x12\t\n\x05QUEUE\x10\x01\x12\r\n\tIMMEDIATE\x10\x02*6\n\x0f\x43hatMessageRole\x12\n\n\x06SYSTEM\x10\x00\x12\x08\n\x04USER\x10\x01\x12\r\n\tASSISTANT\x10\x02*_\n\x12\x43hatDeliveryStatus\x12\x18\n\x14\x44\x45LIVERY_IN_PROGRESS\x10\x00\x12\x15\n\x11\x44\x45LIVERY_COMPLETE\x10\x01\x12\x18\n\x14\x44\x45LIVERY_INTERRUPTED\x10\x02*\xb2\x01\n\x14SessionErrorCategory\x12\x11\n\rERROR_UNKNOWN\x10\x00\x12\x11\n\rERROR_SESSION\x10\x01\x12\x17\n\x13\x45RROR_CONFIGURATION\x10\x02\x12\x12\n\x0e\x45RROR_PROTOCOL\x10\x03\x12\x13\n\x0f\x45RROR_INFERENCE\x10\x04\x12\x0f\n\x0b\x45RROR_AUDIO\x10\x05\x12\r\n\tERROR_TTS\x10\x06\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x07\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'realtime_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SAMPLEFORMAT']._serialized_start=6110
  _globals['_SAMPLEFORMAT']._serialized_end=6218
  _globals['_ELEVENLABSLOCATION']._serialized_start=6220
  _globals['_ELEVENLABSLOCATION']._serialized_end=6267
  _globals['_INFERENCETRIGGERMODE']._serialized_start=6269
  _globals['_INFERENCETRIGGERMODE']._serialized_end=6333
  _globals['_CHATMESSAGEROLE']._serialized_start=6335
  _globals['_CHATMESSAGEROLE']._serialized_end=6389
  _globals['_CHATDELIVERYSTATUS']._serialized_start=6391
  _globals['_CHATDELIVERYSTATUS']._serialized_end=6486
  _globals['_SESSIONERRORCATEGORY']._serialized_start=6489
  _globals['_SESSIONERRORCATEGORY']._serialized_end=6667
  _globals['_TOOLDEFINITION']._serialized_start=77
  _globals['_TOOLDEFINITION']._serialized_end=194
  _globals['_UPDATETOOLDEFINITIONSREQUEST']._serialized_start=196
  _globals['_UPDATETOOLDEFINITIONSREQUEST']._serialized_end=297
  _globals['_TOOLCALLREQUEST']._serialized_start=299
  _globals['_TOOLCALLREQUEST']._serialized_end=387
  _globals['_TOOLCALLRESPONSE']._serialized_start=389
  _globals['_TOOLCALLRESPONSE']._serialized_end=435
  _globals['_DURATION']._serialized_start=437
  _globals['_DURATION']._serialized_end=479
  _globals['_AUDIOLINECONFIGURATION']._serialized_start=482
  _globals['_AUDIOLINECONFIGURATION']._serialized_end=616
  _globals['_VADCONFIGURATION']._serialized_start=619
  _globals['_VADCONFIGURATION']._serialized_end=880
  _globals['_INFERENCECONFIGURATION']._serialized_start=882
  _globals['_INFERENCECONFIGURATION']._serialized_end=950
  _globals['_ELEVENLABSTTSCONFIGURATION']._serialized_start=953
  _globals['_ELEVENLABSTTSCONFIGURATION']._serialized_end=1221
  _globals['_ELEVENLABSVOICESETTINGS']._serialized_start=1223
  _globals['_ELEVENLABSVOICESETTINGS']._serialized_end=1350
  _globals['_HOSTEDVOICEREF']._serialized_start=1352
  _globals['_HOSTEDVOICEREF']._serialized_end=1386
  _globals['_HOSTEDTTSCONFIGURATION']._serialized_start=1388
  _globals['_HOSTEDTTSCONFIGURATION']._serialized_end=1487
  _globals['_TTSCONFIGURATION']._serialized_start=1490
  _globals['_TTSCONFIGURATION']._serialized_end=1671
  _globals['_INITIALIZESESSIONREQUEST']._serialized_start=1674
  _globals['_INITIALIZESESSIONREQUEST']._serialized_end=2157
  _globals['_RECONFIGURESESSIONREQUEST']._serialized_start=2160
  _globals['_RECONFIGURESESSIONREQUEST']._serialized_end=2411
  _globals['_AUDIODATA']._serialized_start=2413
  _globals['_AUDIODATA']._serialized_end=2438
  _globals['_TEXTDATA']._serialized_start=2440
  _globals['_TEXTDATA']._serialized_end=2464
  _globals['_USERINPUT']._serialized_start=2467
  _globals['_USERINPUT']._serialized_end=2693
  _globals['_TRIGGERINFERENCE']._serialized_start=2695
  _globals['_TRIGGERINFERENCE']._serialized_end=2769
  _globals['_EXPORTCHATHISTORYREQUEST']._serialized_start=2771
  _globals['_EXPORTCHATHISTORYREQUEST']._serialized_end=2820
  _globals['_PLAYBACKPOSITIONREPORT']._serialized_start=2822
  _globals['_PLAYBACKPOSITIONREPORT']._serialized_end=2868
  _globals['_DIRECTSPEECH']._serialized_start=2870
  _globals['_DIRECTSPEECH']._serialized_end=2926
  _globals['_CONVERSATIONQUERY']._serialized_start=2928
  _globals['_CONVERSATIONQUERY']._serialized_end=3023
  _globals['_CONVERSATIONQUERYRESULT']._serialized_start=3025
  _globals['_CONVERSATIONQUERYRESULT']._serialized_end=3064
  _globals['_SERVICEBOUNDMESSAGE']._serialized_start=3067
  _globals['_SERVICEBOUNDMESSAGE']._serialized_end=3933
  _globals['_MODELTEXTFRAGMENT']._serialized_start=3935
  _globals['_MODELTEXTFRAGMENT']._serialized_end=3968
  _globals['_MODELAUDIOCHUNK']._serialized_start=3970
  _globals['_MODELAUDIOCHUNK']._serialized_end=4082
  _globals['_CHATHISTORY']._serialized_start=4084
  _globals['_CHATHISTORY']._serialized_end=4157
  _globals['_CHATMESSAGE']._serialized_start=4160
  _globals['_CHATMESSAGE']._serialized_end=4392
  _globals['_CHATMESSAGECONTENT']._serialized_start=4395
  _globals['_CHATMESSAGECONTENT']._serialized_end=4744
  _globals['_CHATTEXTCONTENT']._serialized_start=4746
  _globals['_CHATTEXTCONTENT']._serialized_end=4859
  _globals['_CHATAUDIODATA']._serialized_start=4862
  _globals['_CHATAUDIODATA']._serialized_end=5024
  _globals['_PLAYBACKCLEARBUFFER']._serialized_start=5026
  _globals['_PLAYBACKCLEARBUFFER']._serialized_end=5047
  _globals['_RESPONSEBEGIN']._serialized_start=5049
  _globals['_RESPONSEBEGIN']._serialized_end=5064
  _globals['_RESPONSEEND']._serialized_start=5066
  _globals['_RESPONSEEND']._serialized_end=5079
  _globals['_SESSIONERRORNOTIFICATION']._serialized_start=5082
  _globals['_SESSIONERRORNOTIFICATION']._serialized_end=5230
  _globals['_USERTRANSCRIPTIONRESULT']._serialized_start=5232
  _globals['_USERTRANSCRIPTIONRESULT']._serialized_end=5306
  _globals['_CLIENTBOUNDMESSAGE']._serialized_start=5309
  _globals['_CLIENTBOUNDMESSAGE']._serialized_end=6108
# @@protoc_insertion_point(module_scope)
